"""Shared constants for the CCS Response Planner backend."""

API_PREFIX = "/api"
HEALTH_ROUTE = "/api/health"
PLAN_ROUTE = "/api/plan"
DEFAULT_PORT = 8888
DEFAULT_HOST = "127.0.0.1"
DEFAULT_NUM_THREADS = 100
APP_NAME = "CCS Incident Response Planner"
